API Reference
=============

This section contains the API documentation for the pylint-sort-functions plugin.

Checker Module
--------------

.. automodule:: pylint_sort_functions.checker
   :members:
   :undoc-members:
   :show-inheritance:

Messages Module
---------------

.. automodule:: pylint_sort_functions.messages
   :members:
   :undoc-members:
   :show-inheritance:

Utilities Module
----------------

.. automodule:: pylint_sort_functions.utils
   :members:
   :undoc-members:
   :show-inheritance:

Plugin Registration
-------------------

.. automodule:: pylint_sort_functions
   :members:
   :undoc-members:
   :show-inheritance:
